@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2019 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2020 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -87,6 +87,9 @@ class MinType(object):
     def __eq__(self, other: Any) -> bool:
         return self is other
 
+    def __str__(self) -> str:
+        return "MinType"
+
 
 MINTYPE_SINGLETON = MinType()
 
